@@ -5,7 +5,7 @@ from typing import Optional
 from django.conf import settings
 from django.core.files.storage import FileSystemStorage
 
-from .settings import PARAM
+from .settings import PARAM, USE_PUBLIC_NAMESPACE, PUBLIC_NAMESPACE
 
 
 class TitofistoStorage(FileSystemStorage):
@@ -16,6 +16,11 @@ class TitofistoStorage(FileSystemStorage):
         # Get regular URL from base FileSystemStorage
         raw_url = super().url(name)
 
+        if USE_PUBLIC_NAMESPACE:
+            # Public files are accessible without a token
+            if name.startswith(PUBLIC_NAMESPACE):
+                return raw_url
+
         # Get token and timestamp
         token = self.get_token(name)
 
