@@ -23,6 +23,10 @@ class TitofistoTestCase(TestCase):
         self.test_file_2_name = "franztaxi.dat"
         self.storage.save(self.test_file_2_name, BytesIO(self.test_file_2))
 
+        self.test_file_3 = b"Franz jagt im komplett verwahrlosten Taxi quer durch Bayern"
+        self.test_file_3_name = "public/franztaxi.dat"
+        self.storage.save(self.test_file_3_name, BytesIO(self.test_file_3))
+
         self.param = "titofisto_token"
         self.timeout = 60 * 60
         self.client = Client()
@@ -139,3 +143,24 @@ class TitofistoTestCase(TestCase):
         res = self.client.get(url)
 
         self.assertEqual(res.status_code, 404)
+
+    def test_url(self):
+        """The URL for a file should contain a token."""
+        url1 = self.storage.url(self.test_file_1_name)
+        url2 = self.storage.url(self.test_file_2_name)
+        self.assertIn(self.param, url1)
+        self.assertIn(self.param, url2)
+
+    def test_public_files_url(self):
+        """The URL for a file in the public namespace doesn't contain a token."""
+        url = self.storage.url(self.test_file_3_name)
+        self.assertNotIn(self.param, url)
+
+    def test_public_files_view(self):
+        """A file in the public namespace can be acessed without a token."""
+        self.storage.url(self.test_file_3_name)
+        url = (
+            f"{settings.MEDIA_URL}{self.test_file_3_name}"
+        )
+        res = self.client.get(url)
+        self.assertEqual(res.status_code, 200)  
\ No newline at end of file
