@@ -4,7 +4,7 @@ from django.conf import settings
 from django.http import FileResponse, Http404, HttpRequest
 from django.views import View
 
-from .settings import PARAM, TIMEOUT
+from .settings import PARAM, TIMEOUT, USE_PUBLIC_NAMESPACE, PUBLIC_NAMESPACE
 from .storage import TitofistoStorage
 
 
@@ -13,6 +13,11 @@ class TitofistoMediaView(View):
         # Get storage
         storage = TitofistoStorage()
 
+        if USE_PUBLIC_NAMESPACE:
+            # Public files are directly served without needing a token
+            if name.startswith(PUBLIC_NAMESPACE):
+                return FileResponse(storage._open(name))
+
         # Inspect URL parameter for completeness and extract timestamp
         token = request.GET.get(PARAM, None)
         if token is None:
